==> order-base-1.0.20210107.040549-212-sources.jar: com/rocogz/syy/order/constant/OrderRabbitConstant.java <==
package com.rocogz.syy.order.constant;

/**
 * 订单模块 rabbit 消息 消息常量
 * @author zhangmin
 * @date 2020/6/1
 */
public class OrderRabbitConstant {

    /**
     * 订单模块 使用的交换机
     */
    public static final String ORDER_EXCHANGE = "ORDER_EXCHANGE";

    //延迟队列 即有超时时间的队列
    public static final String CANCEL_TIME_OUT_DELAY_QUEUE = "ORDER_TIMEOUT_DELAY_QUEUE";
    public static final String CANCEL_TIME_OUT_DELAY_ROUTE_KEY = "ORDER_TIMEOUT_DELAY_KEY";

    //存放变成死信的队列
    public static final String CANCEL_TIME_OUT_DEAD_QUEUE = "ORDER_TIMEOUT_DEAD_QUEUE";
    public static final String CANCEL_TIME_OUT_DEAD_ROUTE_KEY = "ORDER_TIMEOUT_DEAD_KEY";


    //三星生活助手商品 支付成功消息推送到 三星助手
    public static final String SAMSUNG_PAY_RESULT_NOTIFY_QUEUE = "ORDER_SAMSUNG_PAY_RESULT_QUEUE";
    public static final String SAMSUNG_PAY_RESULT_NOTIFY_ROUTE_KEY = "ORDER_SAMSUNG_PAY_NOTIFY_KEY";


    //虚拟充值订单 充值消息队列
    public static final String ORDER_DEPOSIT_QUEUE = "ORDER_DEPOSIT_QUEUE";
    public static final String ORDER_DEPOSIT_ROUTE_KEY = "ORDER_DEPOSIT_ROUTE_KEY";



    /** =============> 下面是 虚拟商品订单发货队列 rabbit mq 常量 */
    public static final String ORDER_VIRTUAL_GOODS_DELIVERY_QUEUE = "ORDER_VIRTUAL_GOODS_DELIVERY_QUEUE";
    public static final String ORDER_VIRTUAL_GOODS_DELIVERY_ROUTE_KEY = "GOODS_DELIVERY_ROUTE_KEY";



    /** =============> 下面是 三星订单 状态同步 推送 rabbit mq 常量 */
    public static final String SAMSUNG_UPDATE_STATUS_QUEUE = "ORDER_SAMSUNG_UPDATE_STATUS_QUEUE";

    public static final String SAMSUNG_UPDATE_STATUS_ROUTE_KEY = "ORDER_SAMSUNG_UPDATE_STATUS_ROUTE_KEY";




}

==> order-base-1.0.20210107.071724-214-sources.jar: com/rocogz/syy/order/constant/OrderRabbitConstant.java <==
package com.rocogz.syy.order.constant;

/**
 * 订单模块 rabbit 消息 消息常量
 * @author zhangmin
 * @date 2020/6/1
 */
public class OrderRabbitConstant {

    /**
     * 订单模块 使用的交换机
     */
    public static final String ORDER_EXCHANGE = "ORDER_EXCHANGE";

    //延迟队列 即有超时时间的队列
    public static final String CANCEL_TIME_OUT_DELAY_QUEUE = "ORDER_TIMEOUT_DELAY_QUEUE";
    public static final String CANCEL_TIME_OUT_DELAY_ROUTE_KEY = "ORDER_TIMEOUT_DELAY_KEY";

    //存放变成死信的队列
    public static final String CANCEL_TIME_OUT_DEAD_QUEUE = "ORDER_TIMEOUT_DEAD_QUEUE";
    public static final String CANCEL_TIME_OUT_DEAD_ROUTE_KEY = "ORDER_TIMEOUT_DEAD_KEY";


    //三星生活助手商品 支付成功消息推送到 三星助手
    public static final String SAMSUNG_PAY_RESULT_NOTIFY_QUEUE = "ORDER_SAMSUNG_PAY_RESULT_QUEUE";
    public static final String SAMSUNG_PAY_RESULT_NOTIFY_ROUTE_KEY = "ORDER_SAMSUNG_PAY_NOTIFY_KEY";


    //虚拟充值订单 充值消息队列
    public static final String ORDER_DEPOSIT_QUEUE = "ORDER_DEPOSIT_QUEUE";
    public static final String ORDER_DEPOSIT_ROUTE_KEY = "ORDER_DEPOSIT_ROUTE_KEY";

    public static final String ORDER_DEPOSIT_CALLBACK_QUEUE = "ORDER_DEPOSIT_CALLBACK_QUEUE";
    public static final String ORDER_DEPOSIT_CALLBACK_ROUTE_KEY = "ORDER_DEPOSIT_CALL_BACK_ROUTE_KEY";



    /** =============> 下面是 虚拟商品订单发货队列 rabbit mq 常量 */
    public static final String ORDER_VIRTUAL_GOODS_DELIVERY_QUEUE = "ORDER_VIRTUAL_GOODS_DELIVERY_QUEUE";
    public static final String ORDER_VIRTUAL_GOODS_DELIVERY_ROUTE_KEY = "GOODS_DELIVERY_ROUTE_KEY";



    /** =============> 下面是 三星订单 状态同步 推送 rabbit mq 常量 */
    public static final String SAMSUNG_UPDATE_STATUS_QUEUE = "ORDER_SAMSUNG_UPDATE_STATUS_QUEUE";

    public static final String SAMSUNG_UPDATE_STATUS_ROUTE_KEY = "ORDER_SAMSUNG_UPDATE_STATUS_ROUTE_KEY";




}
